pub enum ToSec1OctetStringError {
NotEcKey,
MissingCoordinate,
InvalidCoordinateType,
UnequalCoordinateLength,
}Expand description
The error type returned when a CoseKey can’t be converted to a SEC1 octet string.
Variants
NotEcKey
The CoseKey is not an elliptic curve iana::KeyType::EC2 key type.
MissingCoordinate
The X or Y coordinate is not present in the key parameters.
InvalidCoordinateType
The X or Y coordinate is an invalid CBOR type.
UnequalCoordinateLength
The X and Y coordinates are not the same length.