pub struct CoseMac {
pub protected: ProtectedHeader,
pub unprotected: Header,
pub payload: Option<Vec<u8>>,
pub tag: Vec<u8>,
pub recipients: Vec<CoseRecipient>,
}Expand description
Structure representing a message with authentication code (MAC).
COSE_Mac = [
Headers,
payload : bstr / nil,
tag : bstr,
recipients :[+COSE_recipient]
]Fields
protected: ProtectedHeaderunprotected: Headerpayload: Option<Vec<u8>>tag: Vec<u8>recipients: Vec<CoseRecipient>Implementations
Sourceimpl CoseMac
impl CoseMac
Sourcepub fn verify_tag<F, E>(&self, external_aad: &[u8], verify: F) -> Result<(), E>
👎Deprecated: Use verify_payload_tag() to ensure payload is present
pub fn verify_tag<F, E>(&self, external_aad: &[u8], verify: F) -> Result<(), E>
Use verify_payload_tag() to ensure payload is present
Verify the tag value using the provided mac function, feeding it
the tag value and the combined to-be-MACed data (in that order).
Panics
This function will panic if the payload has not been set.
Sourcepub fn verify_payload_tag<F, E, G>(
&self,
external_aad: &[u8],
missing_payload_error: G,
verify: F,
) -> Result<(), E>
pub fn verify_payload_tag<F, E, G>( &self, external_aad: &[u8], missing_payload_error: G, verify: F, ) -> Result<(), E>
Verify the tag value using the provided mac function, feeding it
the tag value and the combined to-be-MACed data (in that order).
If the CoseMac has no payload, then missing_payload_error() will
be returned.